%bcond_without docs
%bcond_with llvmjit
%global precise_version %{?epoch:%epoch:}%version-%release

Name:           pg_auto_failover
Version:        2.0
Release:    1%{?dist}
Summary:        Postgres extension and service for automated failover and high-availability

License:        ASL 1.0
URL:            https://github.com/hapostgres/%{name}/
Source0:        https://github.com/hapostgres/%{name}/archive/refs/tags/v%{version}.tar.gz

BuildRequires:  gcc-c++ openssl-devel zlib-devel libxslt-devel readline-devel pam-devel
BuildRequires:  postgresql-static postgresql-server-devel
BuildRequires:  lz4-devel
BuildRequires:  python3-sphinx
%if %{with docs}
BuildRequires: python3-sphinx_rtd_theme graphviz

BuildRequires:tex(cfr-lm.sty) 
BuildRequires: texlive-scheme-basic tex(luatex85.sty) tex(standalone.cls)
BuildRequires: latexmk poppler-utils
%endif


Recommends:     openssl
Requires:       postgresql-server postgresql-contrib


%if %{with docs}
%package docs
Summary:        Extra documentation for pg_auto_failover
License:        ASL 1.0 and MIT and BSD
Requires:       %{name} = %precise_version
BuildArch:      noarch
%endif

%if %{with llvmjit}
%package llvmjit
Summary:        Just-in-time compilation support for pg_auto_failover
License:        ASL 1.0
Requires:       %{name} = %precise_version
Requires:       postgresql-llvmjit
%endif

%description
pg_auto_failover is an extension and service for PostgreSQL that monitors and
manages automated failover for a Postgres cluster. It is optimized for
simplicity and correctness and supports Postgres 10 and newer.
We set up one PostgreSQL server as a monitor node as well as a primary and
secondary node for storing data. The monitor node tracks the health of the
data nodes and implements a failover state machine. On the PostgreSQL nodes,
the pg_autoctl program runs alongside PostgreSQL and runs the necessary
commands to configure synchronous streaming replication.

%if %{with docs}
%description docs
The pg_auto_failover-docs package contains some additional documentation for
pg_auto_failover. Currently, this includes the main documentation in HTML
format.
%endif

%if %{with llvmjit}
%description llvmjit
This packages provides JIT support for pg_auto_failover.
%endif

%prep
%autosetup -n %{name}-%{version} -p2

%build
%{_bindir}/make -O -j8 V=1 VERBOSE=1
%{_bindir}/make man

%if %{with docs}
    %{_bindir}/make docs
%endif

%install
%make_install

for f in docs/_build/man/*\ *; do
    %{__mv} "$f" "${f// /_}";
done

%if %{with llvmjit}
%{__rm} -r %{buildroot}/%{_libdir}/pgsql/bitcode
%endif

%{_bindir}/install -p -D -m 0644 docs/_build/man/*.1 -t %{buildroot}%{_mandir}/man1
%{_bindir}/install -p -D -m 0644 docs/_build/man/*.5 -t %{buildroot}%{_mandir}/man5

%files
%{_bindir}/pg_autoctl
%{_libdir}/pgsql/pgautofailover.so
%{_datadir}/pgsql/extension/pgautofailover*.{sql,control}
%doc %{_mandir}/man{1,5}/pg_auto*.{1,5}* 
%doc {README,CHANGELOG}.md
%license LICENSE

%if %{with docs}
%files docs
%doc docs/_build/html/* {README,CHANGELOG}.md
%endif

%if %{with llvmjit}
%files llvmjit
%dir %{_libdir}/pgsql/bitcode/pgautofailover
%{_libdir}/pgsql/bitcode/pgautofailover/*.bc
%{_libdir}/pgsql/bitcode/pgautofailover.index.bc
%endif

%changelog
* Tue Aug 27 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0-1
- initial build
